@@ -116,7 +116,7 @@ stdmetrics = function(x, y, z, i, a, rn, class, pulseID, dz = 1)
 {
   C  = stdmetrics_ctrl(x, y, z, a)
   Z  = stdmetrics_z(z, dz)
-  I  = stdmetrics_i(i, class, rn)
+  I  = stdmetrics_i(i, z, class, rn)
   RN = stdmetrics_rn(rn, class)
   PU = stdmetrics_pulse(pulseID, rn)
 
@@ -139,6 +139,7 @@ stdmetrics = function(x, y, z, i, a, rn, class, pulseID, dz = 1)
 #'
 #' @param z vector of positive z coordinates
 #' @param dz numeric. The thickness of the layers used (height bin)
+#' @param z0 numeric. The bottom limit of the profile
 #' @return A data.frame containing the bin elevations (z) and the gap fraction for each bin (gf)
 #' @examples
 #' z = c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
@@ -152,15 +153,14 @@ stdmetrics = function(x, y, z, i, a, rn, class, pulseID, dz = 1)
 #' @references Bouvier, M., Durrieu, S., Fournier, R. a, & Renaud, J. (2015).  Generalizing predictive models of forest inventory attributes using an area-based approach with airborne LiDAR data. Remote Sensing of Environment, 156, 322-334. http://doi.org/10.1016/j.rse.2014.10.004
 #' @seealso \link[lidR:LAD]{LAD}
 #' @export gap_fraction_profile
-gap_fraction_profile = function (z, dz = 1)
+gap_fraction_profile = function (z, dz = 1, z0 = 2)
 {
-  maxz = max(z)
 
-  bk = seq(0, ceiling(maxz), dz)
+  bk = seq(floor((min(z)-z0)/dz)*dz+z0, ceiling((max(z)-z0)/dz)*dz+z0, dz)
 
   histogram = graphics::hist(z, breaks = bk, plot = F)
   h = histogram$mids
-  p = histogram$counts/sum(histogram$count)
+  p = histogram$counts/sum(histogram$counts)
 
   p = c(p, 0)
 
@@ -173,7 +173,7 @@ gap_fraction_profile = function (z, dz = 1)
   z = h[-1]
   i = i[-c(1, length(i))]
 
-  return(data.frame(z, gf = i))
+  return(data.frame(z[z>z0], gf = i[z>z0]))
 }
 
 #' Leaf area density
@@ -189,6 +189,7 @@ gap_fraction_profile = function (z, dz = 1)
 #' @param z vector of positive z coordinates
 #' @param dz numeric. The thickness of the layers used (height bin)
 #' @param k numeric. is the extinction coefficient
+#' @param z0 numeric. The bottom limit of the profile
 #' @return A data.frame containing the bin elevations (z) and leaf area density for each bin (lad)
 #' @examples
 #' z = c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
@@ -200,15 +201,15 @@ gap_fraction_profile = function (z, dz = 1)
 #' @references Bouvier, M., Durrieu, S., Fournier, R. a, & Renaud, J. (2015).  Generalizing predictive models of forest inventory attributes using an area-based approach with airborne LiDAR data. Remote Sensing of Environment, 156, 322-334. http://doi.org/10.1016/j.rse.2014.10.004
 #' @seealso \link[lidR:gap_fraction_profile]{gap_fraction_profile}
 #' @export LAD
-LAD = function(z, dz = 1, k = 0.5) # (Bouvier et al. 2015)
+LAD = function(z, dz = 1, k = 0.5, z0 = 2) # (Bouvier et al. 2015)
 {
-	ld = gap_fraction_profile(z, dz)
+	ld = gap_fraction_profile(z, dz, z0)
 
 	if(anyNA(ld))
 	  return(NA_real_)
 
 	lad = ld$gf
-	lad = -log(lad)/k
+	lad = -log(lad)/(k*dz)
 
 	lad[is.infinite(lad)] = NA
 
@@ -380,10 +381,17 @@ stdmetrics_z = function(z, dz = 1)
   zq 	  = as.list(stats::quantile(z, probs))
   names(zq) = paste("zq", probs*100, sep="")
 
-  d = graphics::hist(z, breaks = seq(0, zmax, zmax/10), plot=F)
-  d = d$counts / sum(d$counts)*100
-  d = cumsum(d)[1:9]
-  d = as.list(d)
+  if(zmax <= 0)
+  {
+    d = rep(0, 9)
+  }
+  else
+  {
+    d = graphics::hist(z, breaks = seq(0, zmax, zmax/10), plot=F)
+    d = d$counts / sum(d$counts)*100
+    d = cumsum(d)[1:9]
+    d = as.list(d)
+  }
   names(d) = paste0("zpcum", 1:9)
 
   metrics = list(
@@ -442,7 +450,7 @@ stdmetrics_i = function(i, z = NULL, class = NULL, rn = NULL)
       ipcumzq10 = sum(i[z <= zq[1]])/itot*100,
       ipcumzq30 = sum(i[z <= zq[2]])/itot*100,
       ipcumzq50 = sum(i[z <= zq[3]])/itot*100,
-      ipcumzq70 = sum(i[z <= zq[3]])/itot*100,
+      ipcumzq70 = sum(i[z <= zq[4]])/itot*100,
       ipcumzq90 = sum(i[z <= zq[5]])/itot*100
     )
 
